package com.ruoyi.device.mapper;

import java.util.List;

import com.ruoyi.device.domain.BaseType;
import org.springframework.stereotype.Repository;
import com.ruoyi.device.domain.BaseInfo;

/**
 * 设备基础信息Mapper接口
 * 
 * @author ruoyi
 * @date 2025-05-19
 */
@Repository
public interface BaseInfoMapper 
{
    /**
     * 查询设备基础信息
     * 
     * @param objId 设备基础信息主键
     * @return 设备基础信息
     */
    public BaseInfo selectBaseInfoByObjId(Long objId);

    /**
     * 查询设备基础信息列表
     * 
     * @param baseInfo 设备基础信息
     * @return 设备基础信息集合
     */
    public List<BaseInfo> selectBaseInfoList(BaseInfo baseInfo);

    /**
     * 新增设备基础信息
     * 
     * @param baseInfo 设备基础信息
     * @return 结果
     */
    public int insertBaseInfo(BaseInfo baseInfo);

    /**
     * 修改设备基础信息
     * 
     * @param baseInfo 设备基础信息
     * @return 结果
     */
    public int updateBaseInfo(BaseInfo baseInfo);

    /**
     * 删除设备基础信息
     * 
     * @param objId 设备基础信息主键
     * @return 结果
     */
    public int deleteBaseInfoByObjId(Long objId);

    /**
     * 批量删除设备基础信息
     * 
     * @param objIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteBaseInfoByObjIds(String[] objIds);

    BaseInfo checkDeviceCode(BaseInfo baseInfo);

    BaseInfo selectDeviceInfo(String deviceCode);
}
